@@ -18,7 +18,7 @@ require AutoLoader;
     TEXT_TO_DOWN
     TEXT_TO_ANGLE
 );
-$VERSION = '1.03';
+$VERSION = '1.05';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -62,6 +62,9 @@ Image::Imlib2 - Interface to the Imlib2 image library
   # create a new image
   my $image = Image::Imlib2->new(200, 200);
 
+  # Enable the alpha channel support
+  $image->has_alpha(1);
+
   # set a colour (rgba, so this is transparent orange)
   $image->set_color(255, 127, 0, 127);
 
@@ -162,7 +165,7 @@ format has not been set using image_set_format().
 
   $image->save("out.png");
 
-=head2 image_set_format (format)                                               
+=head2 image_set_format (format)
 
 This will set the image format for future save operations. format is a
 string and may be "jpeg", "tiff", "png", etc. The exact number of
@@ -350,6 +353,62 @@ This will flip/mirror the current image diagonally (good for quick and dirty
 
   $image->flip_diagonal();
 
+=head2 has_alpha (BOOLEAN)
+
+Queries and/or sets the alpha support flag for the image. Note that
+alpha is on by default when you create an image:
+
+   if ($image->has_alpha) {
+      # do something requiring alpha support
+   }
+   # Enable the alpha channel
+   $image->has_alpha(1);
+
+=head2 set_cache_size (INT)
+
+By default, Imlib2 will cache all loaded images (up to some maximum cache
+size) and will use this cache to avoid loading images from disk.
+
+Sets the size of the image cache. Reducing this value will cause the cache to
+be emptied.  You can turn off caching all together by setting this to zero.
+
+Even without a cache, as long as you have a reference to an image in memory
+that image will be returned immediately without checking the disk.
+
+  my $image = Image::Imlib2->load("foo.jpg"); # image loaded from disk
+  ... later, somewhere else, after $image has gone away ...
+  my $image = Image::Imlib2->load("foo.jpg"); # same image, even if changed on disk
+  ... later, somewhere else, after $image has gone away ...
+  Image::Imlib2->set_cache_size(0);
+  my $image  = Image::Imlib2->load("foo.jpg"); # image loaded from disk  
+  my $image2 = Image::Imlib2->load("foo.jpg"); # same image as before, not reloaded 
+
+=head2 get_cache_size ()
+
+Returns the maximum size of the Image cache.
+
+=head2 set_changes_on_disk ()
+
+Called on an Image::Imlib2 instance that you have loaded from disk, this
+method tells imlib that it should take extra care when caching the image
+for this filename.  Next time the load method is called for this image's
+file name Imlib will  check the modification time for the file on disk
+compared to the cached version and take appropriate action.
+
+  my $image = Image::Imlib2->load("foo.jpg");
+  $image->set_changes_on_disk();
+
+  ...later...
+
+  # reloads image from disk if mod time has changed (otherwise use cached)
+  my $image = Image::Imlib2->load("foo.jpg"); 
+
+
+Calling
+this method on a loaded image tells Imlib2 to look at the disk and
+compare mtimes with it's loaded copy - by default, this is not the case,
+so even if a file changes on disk, it won't be re-loaded.
+
 =head1 METHODS (Image::Imlib2::Polygon)
 
 =head2 new
@@ -401,13 +460,9 @@ Returns the current height of the image.
 
 Leon Brocard, leon@astray.com
 
-=head1 CONTRIBUTORS
-
-Sebastian Bohm, Theo Schlossnagle, Joel Rowbottom
-
 =head1 COPYRIGHT
 
-Copyright (c) 2000-3 Leon Brocard. All rights reserved. This program is
+Copyright (c) 2000-5 Leon Brocard. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
